@@ -761,9 +761,20 @@ fn default_tile_color2() -> f32 {
 }
 
 impl Opt {
+    pub fn create_ik_constraints(&self) -> k::Constraints {
+        k::Constraints {
+            position_x: !self.ignore_ik_position_x,
+            position_y: !self.ignore_ik_position_y,
+            position_z: !self.ignore_ik_position_z,
+            rotation_x: !self.ignore_ik_rotation_x,
+            rotation_y: !self.ignore_ik_rotation_y,
+            rotation_z: !self.ignore_ik_rotation_z,
+        }
+    }
+
     #[cfg(target_arch = "wasm32")]
     pub fn from_params() -> Result<Self, crate::Error> {
-        let href = web_sys::window().unwrap().location().href()?;
+        let href = crate::utils::window()?.location().href()?;
         log::debug!("href={}", href);
         let url = url::Url::parse(&href).map_err(|e| e.to_string())?;
         Ok(serde_qs::from_str(url.query().unwrap_or_default()).map_err(|e| e.to_string())?)
